#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 resource-pool
version:              0.2.3.2
visibility:           public
id:                   resource-pool-0.2.3.2-HuMDXx2LvNiFKUxNwBNmWZ
key:                  resource-pool-0.2.3.2-HuMDXx2LvNiFKUxNwBNmWZ
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://github.com/bos/pool
synopsis:             A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.

category:             Data, Database, Network
abi:                  261caf0047bda8c4e7961a4bf7a05a11
exposed:              True
exposed-modules:      Data.Pool
import-dirs:          /usr/lib/ghc-8.10.5/site-local/resource-pool-0.2.3.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/resource-pool-0.2.3.2
hs-libraries:         HSresource-pool-0.2.3.2-HuMDXx2LvNiFKUxNwBNmWZ
depends:
    base-4.14.2.0 hashable-1.3.2.0-GpzwVyCMdDv8NwdC61S1EE
    monad-control-1.0.2.3-Bi4GOATU8bxGtDgK1rR68J stm-2.5.0.1 time-1.9.3
    transformers-0.5.6.2
    transformers-base-0.4.5.2-KzHjyAKDkdpHt6juu1Rjxn
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:
    /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock

haddock-html:         /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

